// OpenGL Extension Exclusions - may be modified before building.
//
// Generated for Mesa Project, Software Rasterizer
// OpenGL v1.4 (2.1 Mesa 7.8.2), using FreeGLUT v20600

#define NO_GL_VERSION_2_0
#define NO_GL_VERSION_1_5
#define NO_GL_3DFX_multisample
#define NO_GL_3DFX_tbuffer
#define NO_GL_APPLE_client_storage
#define NO_GL_APPLE_element_array
#define NO_GL_APPLE_fence
#define NO_GL_APPLE_specular_vector
#define NO_GL_APPLE_transform_hint
#define NO_GL_APPLE_vertex_array_object
#define NO_GL_APPLE_vertex_array_range
#define NO_GL_APPLE_ycbcr_422
#define NO_GL_ARB_color_buffer_float
#define NO_GL_ARB_fragment_shader
#define NO_GL_ARB_half_float_pixel
#define NO_GL_ARB_matrix_palette
#define NO_GL_ARB_pixel_buffer_object
#define NO_GL_ARB_shader_objects
#define NO_GL_ARB_shading_language_100
#define NO_GL_ARB_texture_float
#define NO_GL_ARB_vertex_blend
#define NO_GL_ARB_vertex_buffer_object
#define NO_GL_ARB_vertex_shader
#define NO_GL_ATI_element_array
#define NO_GL_ATI_envmap_bumpmap
#define NO_GL_ATI_fragment_shader
#define NO_GL_ATI_map_object_buffer
#define NO_GL_ATI_pixel_format_float
#define NO_GL_ATI_pn_triangles
#define NO_GL_ATI_separate_stencil
#define NO_GL_ATI_text_fragment_shader
#define NO_GL_ATI_texture_float
#define NO_GL_ATI_vertex_array_object
#define NO_GL_ATI_vertex_attrib_array_object
#define NO_GL_ATI_vertex_streams
#define NO_GL_EXT_422_pixels
#define NO_GL_EXT_clip_volume_hint
#define NO_GL_EXT_cmyka
#define NO_GL_EXT_color_matrix
#define NO_GL_EXT_color_subtable
#define NO_GL_EXT_compiled_vertex_array
#define NO_GL_EXT_convolution
#define NO_GL_EXT_coordinate_frame
#define NO_GL_EXT_cull_vertex
#define NO_GL_EXT_depth_bounds_test
#define NO_GL_EXT_histogram
#define NO_GL_EXT_index_array_formats
#define NO_GL_EXT_index_func
#define NO_GL_EXT_index_material
#define NO_GL_EXT_index_texture
#define NO_GL_EXT_light_texture
#define NO_GL_EXT_misc_attribute
#define NO_GL_EXT_multisample
#define NO_GL_EXT_pixel_buffer_object
#define NO_GL_EXT_pixel_transform
#define NO_GL_EXT_pixel_transform_color_table
#define NO_GL_EXT_texture_filter_anisotropic
#define NO_GL_EXT_texture_perturb_normal
#define NO_GL_EXT_vertex_shader
#define NO_GL_EXT_vertex_weighting
#define NO_GL_GREMEDY_string_marker
#define NO_GL_HP_convolution_border_modes
#define NO_GL_HP_image_transform
#define NO_GL_HP_occlusion_test
#define NO_GL_HP_texture_lighting
#define NO_GL_IBM_cull_vertex
#define NO_GL_IBM_multimode_draw_arrays
#define NO_GL_IBM_rasterpos_clip
#define NO_GL_IBM_vertex_array_lists
#define NO_GL_INGR_color_clamp
#define NO_GL_INGR_interlace_read
#define NO_GL_INTEL_parallel_arrays
#define NO_GL_MESA_resize_buffers
#define NO_GL_MESA_window_pos
#define NO_GL_NV_copy_depth_to_color
#define NO_GL_NV_evaluators
#define NO_GL_NV_fence
#define NO_GL_NV_float_buffer
#define NO_GL_NV_fog_distance
#define NO_GL_NV_fragment_program2
#define NO_GL_NV_half_float
#define NO_GL_NV_multisample_filter_hint
#define NO_GL_NV_occlusion_query
#define NO_GL_NV_packed_depth_stencil
#define NO_GL_NV_pixel_data_range
#define NO_GL_NV_primitive_restart
#define NO_GL_NV_register_combiners
#define NO_GL_NV_register_combiners2
#define NO_GL_NV_texgen_emboss
#define NO_GL_NV_texture_compression_vtc
#define NO_GL_NV_texture_expand_normal
#define NO_GL_NV_texture_shader
#define NO_GL_NV_texture_shader2
#define NO_GL_NV_texture_shader3
#define NO_GL_NV_vertex_array_range
#define NO_GL_NV_vertex_array_range2
#define NO_GL_NV_vertex_program2
#define NO_GL_NV_vertex_program2_option
#define NO_GL_NV_vertex_program3
#define NO_GL_OES_read_format
#define NO_GL_OML_interlace
#define NO_GL_OML_resample
#define NO_GL_OML_subsample
#define NO_GL_PGI_misc_hints
#define NO_GL_PGI_vertex_hints
#define NO_GL_REND_screen_coordinates
#define NO_GL_S3_s3tc
#define NO_GL_SGIS_detail_texture
#define NO_GL_SGIS_fog_function
#define NO_GL_SGIS_multisample
#define NO_GL_SGIS_pixel_texture
#define NO_GL_SGIS_point_line_texgen
#define NO_GL_SGIS_point_parameters
#define NO_GL_SGIS_sharpen_texture
#define NO_GL_SGIS_texture4D
#define NO_GL_SGIS_texture_color_mask
#define NO_GL_SGIS_texture_filter4
#define NO_GL_SGIX_async
#define NO_GL_SGIX_async_histogram
#define NO_GL_SGIX_async_pixel
#define NO_GL_SGIX_blend_alpha_minmax
#define NO_GL_SGIX_calligraphic_fragment
#define NO_GL_SGIX_clipmap
#define NO_GL_SGIX_convolution_accuracy
#define NO_GL_SGIX_depth_pass_instrument
#define NO_GL_SGIX_depth_texture
#define NO_GL_SGIX_flush_raster
#define NO_GL_SGIX_fog_offset
#define NO_GL_SGIX_fog_scale
#define NO_GL_SGIX_fragment_lighting
#define NO_GL_SGIX_framezoom
#define NO_GL_SGIX_igloo_interface
#define NO_GL_SGIX_instruments
#define NO_GL_SGIX_interlace
#define NO_GL_SGIX_ir_instrument1
#define NO_GL_SGIX_list_priority
#define NO_GL_SGIX_pixel_texture
#define NO_GL_SGIX_pixel_tiles
#define NO_GL_SGIX_polynomial_ffd
#define NO_GL_SGIX_reference_plane
#define NO_GL_SGIX_resample
#define NO_GL_SGIX_scalebias_hint
#define NO_GL_SGIX_shadow
#define NO_GL_SGIX_sprite
#define NO_GL_SGIX_subsample
#define NO_GL_SGIX_tag_sample_buffer
#define NO_GL_SGIX_texture_add_env
#define NO_GL_SGIX_texture_coordinate_clamp
#define NO_GL_SGIX_texture_lod_bias
#define NO_GL_SGIX_texture_multi_buffer
#define NO_GL_SGIX_texture_scale_bias
#define NO_GL_SGIX_texture_select
#define NO_GL_SGIX_vertex_preclip
#define NO_GL_SGIX_ycrcb
#define NO_GL_SGIX_ycrcb_subsample
#define NO_GL_SGIX_ycrcba
#define NO_GL_SGI_texture_color_table
#define NO_GL_SUNX_constant_data
#define NO_GL_SUN_convolution_border_modes
#define NO_GL_SUN_global_alpha
#define NO_GL_SUN_mesh_array
#define NO_GL_SUN_slice_accum
#define NO_GL_SUN_triangle_list
#define NO_GL_SUN_vertex
#define NO_GL_WIN_phong_shading
#define NO_GL_WIN_specular_fog
